@@ -89,9 +89,9 @@ renv_hydrate_dependencies <- function(project, packages = NULL) {
 
   if (is.null(packages)) {
 
-    projdeps <- dependencies(project, quiet = TRUE)
+    projdeps <- dependencies(project, quiet = TRUE, dev = TRUE)
     if (!renv_testing() && file.exists("~/.Rprofile")) {
-      profdeps <- dependencies("~/.Rprofile", quiet = TRUE)
+      profdeps <- dependencies("~/.Rprofile", quiet = TRUE, dev = TRUE)
       if (length(projdeps))
         projdeps <- bind_list(list(projdeps, profdeps))
     }
@@ -101,9 +101,9 @@ renv_hydrate_dependencies <- function(project, packages = NULL) {
   }
 
   vprintf("* Discovering package dependencies ... ")
-  ignored <- settings$ignored.packages(project = project)
+  ignored <- renv_project_ignored_packages(project = project)
   packages <- renv_vector_diff(packages, ignored)
-  libpaths <- c(renv_libpaths_user(), renv_libpaths_site(), renv_libpaths_system())
+  libpaths <- renv_hydrate_libpaths()
   all <- renv_package_dependencies(packages, project = project, libpaths = libpaths)
   vwritef("Done!")
 
@@ -111,6 +111,19 @@ renv_hydrate_dependencies <- function(project, packages = NULL) {
 
 }
 
+# NOTE: we don't want to look in user / site libraries when testing
+# on CRAN, as we may accidentally find versions of packages available
+# on CRAN but not that we want to use during tests
+renv_hydrate_libpaths <- function() {
+
+  if (renv_testing()) {
+    renv_libpaths_all()
+  } else {
+    c(renv_libpaths_user(), renv_libpaths_site(), renv_libpaths_system())
+  }
+
+}
+
 # takes a package called 'package' installed at location 'location',
 # copies that package into the cache, and then links from the cache
 # to the (private) library 'library'
